@@ -2,8 +2,8 @@
 #'
 #' `boottest.fixest` is a S3 method that allows for fast wild cluster
 #' bootstrap inference for objects of class fixest by  implementing
-#' the fast wild bootstrap algorithm developed in Roodman et al., 2019 and
-#' implemented in the STATA package `boottest`.
+#' fast wild bootstrap algorithms as developed in Roodman et al., 2019 
+#' and MacKinnon, Nielsen & Webb (2022).
 #'
 #' @param object An object of class fixest and estimated via `fixest::feols()`.
 #' Non-linear models are not supported.
@@ -62,7 +62,6 @@
 #' wild cluster bootstrap via the algorithm outlined in "fast and wild" 
 #' (Roodman et al (2019)). "11" is the default for the heteroskedastic 
 #' bootstrap.
-#' @param seed An integer. Allows to set a random seed. For details, see below.
 #' @param R Hypothesis Vector giving linear combinations of coefficients.
 #' Must be either NULL or a vector of the same length as `param`. If NULL,
 #' a vector of ones of length param.
@@ -113,6 +112,12 @@
 #' @param bootstrapc Logical scalar, FALSE by default. TRUE  to request
 #' bootstrap-c instead of bootstrap-t. Only relevant when
 #' 'engine = "WildBootTests.jl"'
+#' @param sampling 'dqrng' or 'standard'. If 'dqrng', the 'dqrng' package is
+#' used for random number generation (when available). If 'standard', 
+#' functions from the 'stats' package are used when available. 
+#' This argument is mostly a convenience to control random number generation in 
+#' a wrapper package around `fwildclusterboot`, `wildrwolf`. 
+#' I recommend to use the fast' option. 
 #' @param ... Further arguments passed to or from other methods.
 
 #' @importFrom dreamerr check_arg validate_dots
@@ -144,16 +149,12 @@
 #' \item{call}{Function call of boottest.}
 #' \item{engine}{The employed bootstrap algorithm.}
 #' \item{nthreads}{The number of threads employed.}
-#' \item{internal_seed}{The integer value -inherited from set.seed() -
-#' used within boottest() to set the random seed in either R or Julia.
-#' If NULL, no internal seed was created.}
 #'
 #' @export
 #' @method boottest fixest
 #'
 #' @section Setting Seeds:
-#' To guarantee reproducibility, you can either use `boottest()'s` `seed`
-#' function argument, or
+#' To guarantee reproducibility, you need to 
 #' set a global random seed via
 #' + `set.seed()` when using
 #'    1) the lean algorithm (via `engine = "R-lean"`) including the
@@ -179,6 +180,14 @@
 #' }
 #' @section Standard Errors:
 #' `boottest` does not calculate standard errors.
+#' @section Stata, Julia and Python Implementations:
+#' The fast wild cluster bootstrap algorithms are further implemented in the 
+#' following software packages: 
+#' \itemize{
+#' \item Stata:[boottest](https://github.com/droodman/boottest) 
+#' \item Julia:[WildBootTests.jl](https://github.com/droodman/WildBootTests.jl) 
+#' \item Python:[wildboottest](https://github.com/s3alfisc/wildboottest) 
+#' }
 #' @references Roodman et al., 2019, "Fast and wild: Bootstrap inference in
 #'             STATA using boottest", The STATA Journal.
 #'      (<https://ideas.repec.org/p/qed/wpaper/1406.html>)
@@ -238,7 +247,6 @@
 #'   clustid = c("group_id1", "group_id2"),
 #'   fe = "Q1_immigration",
 #'   sign_level = 0.2,
-#'   seed = 8,
 #'   r = 2
 #' )
 #' # test treatment + ideology1 = 2
@@ -294,7 +302,6 @@ boottest.fixest <- function(object,
                             fe = NULL,
                             sign_level = 0.05,
                             conf_int = TRUE,
-                            seed = NULL,
                             R = NULL,
                             r = 0,
                             beta0 = NULL,
@@ -304,6 +311,7 @@ boottest.fixest <- function(object,
                             p_val_type = "two-tailed",
                             tol = 1e-6,
                             maxiter = 10,
+                            sampling = "dqrng",
                             nthreads = getBoottest_nthreads(),
                             ssc = boot_ssc(
                               adj = TRUE,
@@ -334,7 +342,6 @@ boottest.fixest <- function(object,
   check_arg(p_val_type, "charin(two-tailed, equal-tailed,>, <)")
   
   check_arg(conf_int, "logical scalar")
-  check_arg(seed, "scalar integer | NULL")
   check_arg(R, "NULL| scalar numeric | numeric vector")
   check_arg(r, "numeric scalar | NULL")
   check_arg(fe, "character scalar | NULL | formula")
@@ -348,19 +355,36 @@ boottest.fixest <- function(object,
   check_arg(maxmatsize, "scalar integer | NULL")
   check_arg(bootstrapc, "scalar logical")
   
+  check_arg(sampling, "charin(dqrng, standard)")
+  
+  # remind packages users to set a global seed
+  inform_seed(
+    frequency_id = "seed-reminder-boot-fixest", 
+    engine = engine
+  )  
+  
   if(bootstrap_type != "fnw11"){
     if(engine == "R"){
       if(conf_int){
-        message("Confidence Intervals are currently only supported for 
-                the R engine with 'bootstrap_type = 'fnw11' '.")
+        rlang::inform(
+          "Confidence Intervals are currently only supported for 
+                the R engine with 'bootstrap_type = 'fnw11' '.", 
+          use_cli_format = TRUE, 
+          .frequency = "regularly", 
+          .frequency_id = "CI only for fnw algo."
+        )
       }
     }
   }
   
   if (!is.null(beta0)) {
-    stop(
-      "The function argument 'beta0' is deprecated. Please use the
-      function argument 'r' instead, by which it is replaced."
+    rlang::abort(
+      c(
+        "The function argument 'beta0' is deprecated.
+         Please use the function argument 'r' instead,
+         by which it is replaced."
+      ),
+      use_cli_format = TRUE
     )
   }
   
@@ -380,14 +404,9 @@ boottest.fixest <- function(object,
     fe <- attr(terms(fe), "term.labels")
   }
   
-  internal_seed <- set_seed(
-    seed = seed,
-    engine = engine,
-    type = type
-  )
   
   if (!is.null(object$fixef_removed)) {
-    stop(
+    rlang::abort(
       paste(
         "feols() removes fixed effects with the following values: ",
         object$fixef_removed,
@@ -395,7 +414,8 @@ boottest.fixest <- function(object,
         account for this deletion. Therefore, please exclude such fixed
         effects prior to estimation with feols(). You can find them listed
         under '$fixef_removed' of your fixest object."
-      )
+      ), 
+      use_cli_format = TRUE
     )
   }
   
@@ -496,143 +516,40 @@ boottest.fixest <- function(object,
   
   boot_vcov <- boot_coef <- NULL
   
-  if (engine == "R") {
-    
-    if(bootstrap_type == "fnw11"){
-      
-      res <- boot_algo2(
-        preprocessed_object = preprocess,
-        boot_iter = B,
-        point_estimate = point_estimate,
-        impose_null = impose_null,
-        r = r,
-        sign_level = sign_level,
-        param = param,
-        # seed = seed,
-        p_val_type = p_val_type,
-        nthreads = nthreads,
-        type = type,
-        full_enumeration = full_enumeration,
-        small_sample_correction = small_sample_correction,
-        conf_int = conf_int,
-        maxiter = maxiter,
-        tol = tol
-      )
-      
-      
-    } else {
-      
-      # need some function checks here ... 
-      check_boot_algo3(
-        weights = stats::weights(object), 
-        clustid = clustid,
-        fe = fe,
-        bootstrap_type = bootstrap_type, 
-        R = R_long, 
-        r = r
-      )
-      
-      res <- boot_algo3(
-        preprocessed_object = preprocess,
-        B = B,
-        bootstrap_type = bootstrap_type,
-        r = r,
-        sign_level = sign_level,
-        param = param,
-        p_val_type = p_val_type,
-        nthreads = nthreads,
-        type = type,
-        full_enumeration = full_enumeration,
-        small_sample_correction = small_sample_correction,
-        seed = internal_seed, 
-        object = object, 
-        impose_null = impose_null
-      )
-      
-      boot_vcov <- boot_coef <- NULL
-      boot_vcov <- res$boot_vcov
-      boot_coef <- res$boot_coef
-      
-      conf_int <- p_grid_vals <- grid_vals <- FALSE
-      
-      
-    }
-    
-  } else if (engine == "R-lean") {
-    check_r_lean(
-      weights = stats::weights(object),
-      clustid = clustid,
-      fe = fe, 
-      impose_null = impose_null
-    )
-    
-    if(bootstrap_type == "fnw11"){
-      bootstrap_type <- "11"
-    }
-    
-    res <- boot_algo1(
-      preprocessed_object = preprocess,
-      boot_iter = B,
-      point_estimate = point_estimate,
-      impose_null = impose_null,
-      r = r,
-      sign_level = sign_level,
-      param = param,
-      p_val_type = p_val_type,
+  res <- 
+    run_bootstrap(
+      object = object, 
+      engine = engine, 
+      preprocess = preprocess,  
       bootstrap_type = bootstrap_type, 
-      nthreads = nthreads,
-      type = type,
-      full_enumeration = full_enumeration,
-      small_sample_correction = small_sample_correction,
-      heteroskedastic = heteroskedastic,
-      seed = internal_seed
-    )
-    conf_int <- p_grid_vals <- grid_vals <- FALSE
-  } else if (engine == "WildBootTests.jl") {
-    julia_ssc <- get_ssc_julia(ssc)
-    small <- julia_ssc$small
-    clusteradj <- julia_ssc$clusteradj
-    clustermin <- julia_ssc$clustermin
-    fedfadj <- 0L
+      B = B, 
+      point_estimate = point_estimate, 
+      impose_null = impose_null, 
+      r = r, 
+      sign_level = sign_level, 
+      param = param, 
+      p_val_type = p_val_type, 
+      nthreads = nthreads, 
+      type = type, 
+      full_enumeration = full_enumeration, 
+      small_sample_correction = small_sample_correction, 
+      conf_int = conf_int, 
+      maxiter = maxiter, 
+      tol = tol, 
+      clustid = clustid, 
+      fe = fe, 
+      R_long = R_long, 
+      heteroskedastic = heteroskedastic, 
+      ssc = ssc, 
+      floattype = floattype ,
+      bootstrapc = bootstrapc ,
+      getauxweights = getauxweights ,
+      maxmatsize = maxmatsize, 
+      sampling = sampling, 
+      bootcluster = bootcluster
+      
+  )
     
-    if (ssc[["fixef.K"]] != "none") {
-      x <- format_message(
-        "Currently, boottest() only supports fixef.K = 'none'."
-      )
-      message(x)
-    }
-    
-    res <- boot_algo_julia(
-      preprocess = preprocess,
-      impose_null = impose_null,
-      r = r,
-      B = B,
-      bootcluster = bootcluster,
-      clustid = clustid,
-      sign_level = sign_level,
-      conf_int = conf_int,
-      tol = tol,
-      p_val_type = p_val_type,
-      type = type,
-      floattype = floattype,
-      bootstrapc = bootstrapc,
-      # LIML = LIML,
-      # ARubin = ARubin,
-      getauxweights = getauxweights,
-      internal_seed = internal_seed,
-      maxmatsize = maxmatsize,
-      # fweights = 1L,
-      small = small,
-      clusteradj = clusteradj,
-      clustermin = clustermin,
-      fe = fe,
-      fedfadj = fedfadj, 
-      bootstrap_type = bootstrap_type
-    )
-  } 
-  
-  
-  
   # collect results
   res_final <- list(
     point_estimate = point_estimate,
@@ -657,7 +574,6 @@ boottest.fixest <- function(object,
     r = r,
     engine = engine,
     nthreads = nthreads,
-    internal_seed = internal_seed, 
     boot_vcov = boot_vcov, 
     boot_coef = boot_coef
   )
