@@ -2,14 +2,19 @@ test_that("Do different, but equivalent ways to specify
           linear models lead to equivalent results?", {
   
   skip_on_cran()
-
+  skip_if_not(
+      fwildclusterboot:::find_proglang("julia"), 
+      message = "skip test as julia installation not found."
+  )    
+  
+  set.seed(2351)
+  dqrng::dqset.seed(2351)
+  
   requireNamespace("fixest")
   requireNamespace("lfe")
             
-            
-  if(TRUE){
-    print_results <- FALSE
-    
+  print_results <- FALSE
+
     data1 <<-
       fwildclusterboot:::create_data(
         N = 10000,
@@ -185,13 +190,15 @@ test_that("Do different, but equivalent ways to specify
       for (engine in c("R", "WildBootTests.jl")) {
         # boottest()
         cat("boottest()", "\n")
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_lm_", engine),
                suppressWarnings(
                  boottest(
                    object = lm_fit,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -202,13 +209,15 @@ test_that("Do different, but equivalent ways to specify
                envir = .GlobalEnv
         )
         
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest1_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit1,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = ~treatment,
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -218,13 +227,16 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest2_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit2,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -234,13 +246,16 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest3_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit3,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -250,13 +265,16 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest4_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit4,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -266,13 +284,16 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest5_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit5,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -282,13 +303,16 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest6_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit6,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -298,13 +322,16 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest7_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit7,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -314,13 +341,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest8_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit8,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -330,13 +361,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest9_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit9,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -346,13 +381,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest10_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit10,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -362,13 +401,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest11_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit11,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -378,13 +421,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest12_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit12,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -394,13 +441,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest13_", engine),
                suppressWarnings(
                  boottest(
                    object = feols_fit13,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -411,6 +462,9 @@ test_that("Do different, but equivalent ways to specify
                envir = .GlobalEnv
         )
         
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest6fe_", engine),
                suppressWarnings(
                  boottest(
@@ -418,7 +472,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = ~Q1_immigration,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -428,6 +482,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest7fe_", engine),
                suppressWarnings(
                  boottest(
@@ -435,7 +493,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q1_immigration",
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -445,6 +503,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest8fe_", engine),
                suppressWarnings(
                  boottest(
@@ -452,7 +514,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q1_immigration",
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -462,6 +524,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest9fe_", engine),
                suppressWarnings(
                  boottest(
@@ -469,7 +535,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q1_immigration",
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -479,6 +545,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest10fe_", engine),
                suppressWarnings(
                  boottest(
@@ -486,7 +556,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q1_immigration",
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -496,6 +566,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         # why suddenly fe = Q2_defense? Should give the same models
         assign(paste0("boot_fixest11fe_", engine),
                suppressWarnings(
@@ -504,7 +578,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q2_defense",
                    B = 19999,
-                   seed = 911,
+                   
                    param = ~treatment,
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -514,6 +588,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_fixest12fe_", engine),
                suppressWarnings(
                  boottest(
@@ -521,24 +599,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q2_defense",
                    B = 19999,
-                   seed = 911,
-                   param = "treatment",
-                   conf_int = TRUE,
-                   ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
-                   engine = engine,
-                   floattype = "Float64"
-                 )
-               ),
-               envir = .GlobalEnv
-        )
-        assign(paste0("boot_fixest13fe_", engine),
-               suppressWarnings(
-                 boottest(
-                   object = feols_fit13,
-                   clustid = clustid,
-                   fe = "Q2_defense",
-                   B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -549,13 +610,37 @@ test_that("Do different, but equivalent ways to specify
                envir = .GlobalEnv
         )
         
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
+        assign(paste0("boot_fixest13fe_", engine),
+               suppressWarnings(
+                 boottest(
+                   object = feols_fit13,
+                   clustid = clustid,
+                   fe = "Q2_defense",
+                   B = 19999,
+                   
+                   param = "treatment",
+                   conf_int = TRUE,
+                   ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
+                   engine = engine,
+                   floattype = "Float64"
+                 )
+               ),
+               envir = .GlobalEnv
+        )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm1_", engine),
                suppressWarnings(
                  boottest(
                    object = felm_fit1,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = ~treatment,
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -565,13 +650,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm2_", engine),
                suppressWarnings(
                  boottest(
                    object = felm_fit2,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -581,13 +670,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm3_", engine),
                suppressWarnings(
                  boottest(
                    object = felm_fit3,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -597,13 +690,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm4_", engine),
                suppressWarnings(
                  boottest(
                    object = felm_fit4,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -613,13 +710,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm5_", engine),
                suppressWarnings(
                  boottest(
                    object = felm_fit5,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -629,13 +730,17 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm6_", engine),
                suppressWarnings(
                  boottest(
                    object = felm_fit6,
                    clustid = clustid,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -646,6 +751,9 @@ test_that("Do different, but equivalent ways to specify
                envir = .GlobalEnv
         )
         
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm4fe_", engine),
                suppressWarnings(
                  boottest(
@@ -653,7 +761,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = ~Q1_immigration,
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -663,6 +771,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm5fe_", engine),
                suppressWarnings(
                  boottest(
@@ -670,7 +782,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q1_immigration",
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -680,6 +792,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm6fe_", engine),
                suppressWarnings(
                  boottest(
@@ -687,7 +803,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q1_immigration",
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -697,6 +813,10 @@ test_that("Do different, but equivalent ways to specify
                ),
                envir = .GlobalEnv
         )
+        
+        set.seed(8965)
+        dqrng::dqset.seed(765)
+        
         assign(paste0("boot_felm7fe_", engine),
                suppressWarnings(
                  boottest(
@@ -704,7 +824,7 @@ test_that("Do different, but equivalent ways to specify
                    clustid = clustid,
                    fe = "Q2_defense",
                    B = 19999,
-                   seed = 911,
+                   
                    param = "treatment",
                    conf_int = TRUE,
                    ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
@@ -720,6 +840,7 @@ test_that("Do different, but equivalent ways to specify
         if (engine == "WildBootTests.jl") {
           cat("mboottest()", "\n")
           
+          set.seed(86908)
           assign(paste0("wboot_lm_", engine),
                  suppressWarnings(
                    mboottest(
@@ -727,7 +848,7 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
@@ -735,6 +856,8 @@ test_that("Do different, but equivalent ways to specify
                  envir = .GlobalEnv
           )
           
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest1_", engine),
                  suppressWarnings(
                    mboottest(
@@ -742,13 +865,15 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest2_", engine),
                  suppressWarnings(
                    mboottest(
@@ -756,13 +881,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest3_", engine),
                  suppressWarnings(
                    mboottest(
@@ -770,13 +898,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest4_", engine),
                  suppressWarnings(
                    mboottest(
@@ -784,13 +915,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest5_", engine),
                  suppressWarnings(
                    mboottest(
@@ -798,7 +932,7 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
@@ -808,6 +942,9 @@ test_that("Do different, but equivalent ways to specify
           # why lm_fit? Because mboottest() estimates without fixed
           # effects, so R needs to be of dimension of
           # length(names(coef(object)))
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest6_", engine),
                  suppressWarnings(
                    mboottest(
@@ -815,13 +952,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R2,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest7_", engine),
                  suppressWarnings(
                    mboottest(
@@ -829,13 +969,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R2,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest8_", engine),
                  suppressWarnings(
                    mboottest(
@@ -843,13 +986,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R2,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_fixest9_", engine),
                  suppressWarnings(
                    mboottest(
@@ -857,13 +1003,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R2,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(
             paste0("wboot_fixest10_", engine),
             suppressWarnings(
@@ -872,7 +1021,7 @@ test_that("Do different, but equivalent ways to specify
                 R = R2,
                 clustid = clustid,
                 B = 19999,
-                seed = 911,
+                
                 ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                 floattype = "Float64"
               )
@@ -880,6 +1029,8 @@ test_that("Do different, but equivalent ways to specify
             envir = .GlobalEnv
           )
           
+          set.seed(86908)
+          
           assign(
             paste0("wboot_fixest6fe_", engine),
             suppressWarnings(
@@ -889,13 +1040,16 @@ test_that("Do different, but equivalent ways to specify
                 clustid = clustid,
                 fe = "Q1_immigration",
                 B = 19999,
-                seed = 911,
+                
                 ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                 floattype = "Float64"
               )
             ),
             envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(
             paste0("wboot_fixest7fe_", engine),
             suppressWarnings(
@@ -905,13 +1059,16 @@ test_that("Do different, but equivalent ways to specify
                 clustid = clustid,
                 fe = "Q1_immigration",
                 B = 19999,
-                seed = 911,
+                
                 ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                 floattype = "Float64"
               )
             ),
             envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(
             paste0("wboot_fixest8fe_", engine),
             suppressWarnings(
@@ -921,13 +1078,16 @@ test_that("Do different, but equivalent ways to specify
                 clustid = clustid,
                 fe = "Q1_immigration",
                 B = 19999,
-                seed = 911,
+                
                 ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                 floattype = "Float64"
               )
             ),
             envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(
             paste0("wboot_fixest9fe_", engine),
             suppressWarnings(
@@ -937,13 +1097,16 @@ test_that("Do different, but equivalent ways to specify
                 clustid = clustid,
                 fe = "Q1_immigration",
                 B = 19999,
-                seed = 911,
+                
                 ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                 floattype = "Float64"
               )
             ),
             envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(
             paste0("wboot_fixest10fe_", engine),
             suppressWarnings(
@@ -953,13 +1116,16 @@ test_that("Do different, but equivalent ways to specify
                 clustid = clustid,
                 fe = "Q1_immigration",
                 B = 19999,
-                seed = 911,
+                
                 ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                 floattype = "Float64"
               )
             ),
             envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           # why suddenly fe = Q2_defense? Should give the same models
           assign(
             paste0("wboot_fixest11fe_", engine),
@@ -970,7 +1136,7 @@ test_that("Do different, but equivalent ways to specify
                 clustid = clustid,
                 fe = "Q2_defense",
                 B = 19999,
-                seed = 911,
+                
                 ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                 floattype = "Float64"
               )
@@ -978,6 +1144,8 @@ test_that("Do different, but equivalent ways to specify
             envir = .GlobalEnv
           )
           
+          set.seed(86908)
+          
           assign(paste0("wboot_felm1_", engine),
                  suppressWarnings(
                    mboottest(
@@ -985,13 +1153,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm2_", engine),
                  suppressWarnings(
                    mboottest(
@@ -999,13 +1170,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm3_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1013,13 +1187,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R1,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm4_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1027,13 +1204,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R2,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm5_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1041,13 +1221,16 @@ test_that("Do different, but equivalent ways to specify
                      R = R2,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm6_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1055,7 +1238,7 @@ test_that("Do different, but equivalent ways to specify
                      R = R2,
                      clustid = clustid,
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
@@ -1063,6 +1246,8 @@ test_that("Do different, but equivalent ways to specify
                  envir = .GlobalEnv
           )
           
+          set.seed(86908)
+          
           assign(paste0("wboot_felm4fe_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1071,13 +1256,16 @@ test_that("Do different, but equivalent ways to specify
                      clustid = clustid,
                      fe = "Q1_immigration",
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm5fe_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1086,13 +1274,16 @@ test_that("Do different, but equivalent ways to specify
                      clustid = clustid,
                      fe = "Q1_immigration",
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm6fe_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1101,13 +1292,16 @@ test_that("Do different, but equivalent ways to specify
                      clustid = clustid,
                      fe = "Q1_immigration",
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
                  ),
                  envir = .GlobalEnv
           )
+          
+          set.seed(86908)
+          
           assign(paste0("wboot_felm7fe_", engine),
                  suppressWarnings(
                    mboottest(
@@ -1116,7 +1310,7 @@ test_that("Do different, but equivalent ways to specify
                      clustid = clustid,
                      fe = "Q2_defense",
                      B = 19999,
-                     seed = 911,
+                     
                      ssc = boot_ssc(adj = FALSE, cluster.adj = FALSE),
                      floattype = "Float64"
                    )
@@ -1233,10 +1427,7 @@ test_that("Do different, but equivalent ways to specify
     
     create_models(clustid = c("group_id1", "group_id2"))
     run_tests()
-    
-  } else {
-    message("test-method_equivalence.R I skipped as JULIA_BINDR not found.")
-  }
+
     
   })
 
